@@ -30,3 +30,8 @@
 #' Ideological alignment of 500 domains based on facebook data
 #' @references Bakshy, Eytan, Solomon Messing, and Lada A. Adamic. "Exposure to ideologically diverse news and opinion on Facebook." Science 348.6239 (2015): 1130-1132.
 "bakshy"
+
+#' Fake data
+#'
+#' Small fake webtracking data for testing purpose
+"fake_tracking"
